@@ -1,21 +1,21 @@
-dissvar.grp <- function(mdis, group=NULL, ...){
+dissvar.grp <- function(diss, group=NULL, ...){
 
-	isdist <- inherits(mdis, "dist")
+	isdist <- inherits(diss, "dist")
 	if (isdist) {
-		n <- attr(mdis, "Size")
-	} else if (is.matrix(mdis)) {
-		n <- nrow(mdis)
+		n <- attr(diss, "Size")
+	} else if (is.matrix(diss)) {
+		n <- nrow(diss)
 	} else {
-		stop("mdis argument should be a dist object or a dissimilarity matrix")
+		stop("diss argument should be a dist object or a dissimilarity matrix")
 	}
 
     grp <- group
     if (is.null(grp)) {
         grp <- rep(1, n)
     }
-    
+
     if (length(grp) != n){
-        stop("length(grp) not compatible with size of mdis",
+        stop("length(grp) not compatible with size of diss",
             call. = FALSE)
         }
 
@@ -24,11 +24,11 @@ dissvar.grp <- function(mdis, group=NULL, ...){
     v <- vector("double",length(levg))
     ## We need to transform into a matrix to subset
     ## an alternative would be use the subset.dist function from package cba
-    if (isdist) mdis <- as.matrix(mdis)
+    if (isdist) diss <- as.matrix(diss)
     for (i in 1:length(levg))
         {
         ig <- which(grp==levg[i])
-        v[[i]] <- dissvar(mdis[ig,ig], ...)
+        v[[i]] <- dissvar(diss[ig,ig], ...)
         }
     names(v) <- levg
     return(v)
